ProSHADE: Class Members - Functions

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

### - f -

- figureIndexStartStop() : ProSHADE_internal_data::ProSHADE_data
- findAllPeaks() : ProSHADE_internal_spheres::ProSHADE_rotFun_sphere
- findBestCScore() : ProSHADE_internal_data::ProSHADE_data
- findBestDScore() : ProSHADE_internal_data::ProSHADE_data
- findCyclicPointGroupsGivenFold() : ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup
- findIScore() : ProSHADE_internal_data::ProSHADE_data
- findMapCOM() : ProSHADE_internal_data::ProSHADE_data
- findOScore() : ProSHADE_internal_data::ProSHADE_data
- findRequestedCSymmetryFromAngleAxis() : ProSHADE_internal_data::ProSHADE_data
- findTScore() : ProSHADE_internal_data::ProSHADE_data